==> bomiot-0.9.11.tar.gz: bomiot-0.9.11/bomiot/templates/src/i18n/zh-CN/index.js <==
// This is just an example,
// so you can safely delete all default props below

export default {
  failed: '失败',
  success: '成功',
  title: 'Bomiot',
  description: 'GreaterWMS开源仓库管理系统',
  keywords: 'greaterwms, 聚商汇wms,wms-system,open source wms system,开源wms,开源仓库管理软件,warehouse management system, free wms',
  expireNotice: `授权Key将在{days}天内到期，请使用'bomiot keys'重新获取授权key`,
  expired: "授权Key已过期，请使用'bomiot keys'重新获取授权key",
  gohome: '回到首页',
  cancel: '取消',
  submit: '提交',
  login: '登入',
  register: '注册',
  passworderror: '两次输入的密码不一样',
  logout: '退出',
  logoutnotice: '欢迎再来',
  username: '用户名',
  password: '输入密码',
  password1: '输入密码',
  password2: '再次输入密码',
  usererror: '用户名或密码不能为空',
  nodata: '没有请求到任何数据',
  total: '总共：',
  page: '页',
  per_page: '每页多少行',
  refresh: '刷新',
  new: '新增',
  edit: '修改数据',
  delete: '删除数据',
  refreshdata: '刷新数据',
  newUser: '新增用户',
  createuser: '请输入用户名，默认密码是你输入的用户名',
  changepassword: '修改密码',
  changePWD: '请输入你的新密码，最少3位',
  sucesschangepwd: '修改密码成功',
  setteam: '设置用户组',
  chooseteam: '选择该用户需要的用户组',
  setdepartment: '设置部门',
  choosedepartment: '选择该用户需要的部门',
  isactive: '未锁',
  isnotactive: '锁定',
  deleteuser: '删除用户',
  email: 'E-Mail',
  date_joined: '创建时间',
  last_login: '最后登入时间',
  created_time: '创建时间',
  updated_time: '更新时间',
  action: '操作',
  confirmnotice: '删除数据不可逆，请确认操作！！！',
  contents: '目录',
  copySuccess: '复制成功',
  menuTab: {
    standard: '基础',
    server: '服务器',
  },
  menuLink: {
    home: '首页',
    user: '用户列表',
    team: '用户组',
    department: '部门管理',
    example: '示例'
  },
  upload: {
    center: '上传中心',
    clear: '清空所有',
    remove: '移除这个文件',
    choose: '选择你要上传的文件，并上传服务器',
    add: '增加上传文件',
    server: '上传服务器',
    abort: '终止上传',
    delete: '删除这个文件',
    status: '上传状态: ',
    idle: '挂载',
    failed: '上传失败',
    uploaded: '上传成功'
  },
  doc: {
    center: '文件中心',
    name: '文件名',
    type: '类型',
    size: '大小',
    owner: '所属',
    share : '分享',
    shared_to: '选择你想要分享给的用户',
    delete: '删除文件',
    download: '下载文件',
    deletefile: '删除文件',
    deletefilenotice: '确认是否要删除这个文件',
    uploaded: 'Uploaded',
  },
  department: {
    new: '新增部门',
    create: '请输入部门名称',
    change: '修改部门名称',
    confirmchange: '修改后的部门名称，将会影响到所有使用该部门的用户',
    delete: '删除部门',
    name: '部门名称',
  },
  team: {
    new: '新增用户组',
    create: '请输入用户组名称',
    change: '修改用户组名称',
    changeteam: '修改后的用户组名称，将会影响到所有使用该用户组的用户',
    permission: '设置权限',
    choosepermission: '选择该用户组需要的权限',
    delete: '删除用户组',
    name: '用户组名称',
  },
  pypi: {
    category: '目录',
    downloads: '下载量',
    percent: '百分比',
    date: '日期',
  },
  pid: {
    pid: 'PID',
    name: '名称',
    memory: '内存',
    memory_usage: '内存使用率',
    cpu_usage: 'CPU使用率',
  },
  cpu: {
    cpu_frequency: 'CPU当前频率',
    min_cpu_frequency: '最小频率',
    max_cpu_frequency: '最大频率',
    physical_cores: '物理核心数',
    logical_cores: '逻辑核心数',
    cpu_usage: 'CPU使用率',
  },
  memory: {
    total: '总内存',
    used: '已使用内存',
    free: '空闲内存',
    percent: '内存使用率',
    swap_total: '总交换空间',
    swap_used: '已使用交换空间',
    swap_free: '可用交换空间',
    swap_percent: '交换空间使用率'
  },
  disk: {
    device: '分区',
    mountpoint: '挂载点',
    total: '总容量',
    used: '已使用容量',
    free: '空闲容量',
    percent: '磁盘使用率'
  },
  network: {
    bytes_sent: '发送字节数',
    bytes_recv: '接收字节数',
  },
  example: {
    create: '创建数据',
    update: '修改数据',
    delete: '删除数据',
    value: '值',
    status: '状态',
    description: '描述',
    error: '数据必须超过1个字符'
  },
  400: '错误请求(400)',
  401: '未取得授权(401)',
  403: '拒绝访问(403)',
  404: '资源不存在(404)',
  405: '该功能被禁用(405)',
  408: '请求超时(408)',
  409: '数据冲突(409)',
  410: '数据已删除(410)',
  500: '服务器错误(500)',
  501: '服务未实现(501)',
  502: '网络错误(502)',
  503: '服务不可用(503)',
  504: '网络超时(504)',
  505: 'HTTP版本不受支持(505)'
}

==> bomiot-1.1.16.tar.gz: bomiot-1.1.16/bomiot/templates/src/i18n/zh-CN/index.js <==
// This is just an example,
// so you can safely delete all default props below

export default {
  failed: '失败',
  success: '成功',
  title: 'Bomiot',
  description: 'GreaterWMS开源仓库管理系统',
  keywords: 'greaterwms, 聚商汇wms,wms-system,open source wms system,开源wms,开源仓库管理软件,warehouse management system, free wms',
  expireNotice: `授权Key将在{days}天内到期，请使用'bomiot keys'重新获取授权key`,
  expired: "授权Key已过期，请使用'bomiot keys'重新获取授权key",
  gohome: '回到首页',
  cancel: '取消',
  submit: '提交',
  login: '登入',
  register: '注册',
  passworderror: '两次输入的密码不一样',
  logout: '退出',
  logoutnotice: '欢迎再来',
  username: '用户名',
  password: '输入密码',
  password1: '输入密码',
  password2: '再次输入密码',
  usererror: '用户名或密码不能为空',
  nodata: '没有请求到任何数据',
  total: '总共：',
  page: '页',
  per_page: '每页多少行',
  refresh: '刷新',
  new: '新增',
  edit: '修改数据',
  delete: '删除数据',
  refreshdata: '刷新数据',
  newUser: '新增用户',
  createuser: '请输入用户名，默认密码是你输入的用户名',
  changepassword: '修改密码',
  changePWD: '请输入你的新密码，最少3位',
  sucesschangepwd: '修改密码成功',
  setteam: '设置用户组',
  chooseteam: '选择该用户需要的用户组',
  setdepartment: '设置部门',
  choosedepartment: '选择该用户需要的部门',
  isactive: '未锁',
  isnotactive: '锁定',
  deleteuser: '删除用户',
  email: 'E-Mail',
  date_joined: '创建时间',
  last_login: '最后登入时间',
  created_time: '创建时间',
  updated_time: '更新时间',
  action: '操作',
  confirmnotice: '删除数据不可逆，请确认操作！！！',
  contents: '目录',
  copySuccess: '复制成功',
  menuTab: {
    standard: '基础',
    server: '服务器',
    basic: '入门',
    db: '数据库',
    signals: '信号',
    component: '组件',
    rust_component: 'Rust组件',
  },
  menuLink: {
    home: '首页',
    inscription: '寄语',
    user: '用户列表',
    team: '用户组',
    department: '部门管理',
    example: '示例',
    terminal: '终端',
    structure: '结构',
    permission: '权限',
    scheduler: '定时任务',
    observer: '实时文件',
    server: '服务器监控',
    data: '数据监控',
    interaction: '交互',
  },
  upload: {
    center: '上传中心',
    clear: '清空所有',
    remove: '移除这个文件',
    choose: '选择你要上传的文件，并上传服务器',
    add: '增加上传文件',
    server: '上传服务器',
    abort: '终止上传',
    delete: '删除这个文件',
    status: '上传状态: ',
    idle: '挂载',
    failed: '上传失败',
    uploaded: '上传成功'
  },
  doc: {
    center: '文件中心',
    name: '文件名',
    type: '类型',
    size: '大小',
    owner: '所属',
    share : '分享',
    shared_to: '选择你想要分享给的用户',
    delete: '删除文件',
    preview: '预览文件',
    download: '下载文件',
    deletefile: '删除文件',
    deletefilenotice: '确认是否要删除这个文件',
    uploaded: 'Uploaded',
  },
  department: {
    new: '新增部门',
    create: '请输入部门名称',
    change: '修改部门名称',
    confirmchange: '修改后的部门名称，将会影响到所有使用该部门的用户',
    delete: '删除部门',
    name: '部门名称',
  },
  team: {
    new: '新增用户组',
    create: '请输入用户组名称',
    change: '修改用户组名称',
    changeteam: '修改后的用户组名称，将会影响到所有使用该用户组的用户',
    permission: '设置权限',
    choosepermission: '选择该用户组需要的权限',
    delete: '删除用户组',
    name: '用户组名称',
  },
  pypi: {
    category: '目录',
    downloads: '下载量',
    percent: '百分比',
    date: '日期',
  },
  pid: {
    pid: 'PID',
    name: '名称',
    memory: '内存',
    memory_usage: '内存使用率',
    cpu_usage: 'CPU使用率',
  },
  cpu: {
    cpu_frequency: 'CPU当前频率',
    min_cpu_frequency: '最小频率',
    max_cpu_frequency: '最大频率',
    physical_cores: '物理核心数',
    logical_cores: '逻辑核心数',
    cpu_usage: 'CPU使用率',
  },
  memory: {
    total: '总内存',
    used: '已使用内存',
    free: '空闲内存',
    percent: '内存使用率',
    swap_total: '总交换空间',
    swap_used: '已使用交换空间',
    swap_free: '可用交换空间',
    swap_percent: '交换空间使用率'
  },
  disk: {
    device: '分区',
    mountpoint: '挂载点',
    total: '总容量',
    used: '已使用容量',
    free: '空闲容量',
    percent: '磁盘使用率'
  },
  network: {
    bytes_sent: '发送字节数',
    bytes_recv: '接收字节数',
  },
  example: {
    create: '创建数据',
    update: '修改数据',
    delete: '删除数据',
    value: '值',
    status: '状态',
    description: '描述',
    error: '数据必须超过1个字符'
  },
  400: '错误请求(400)',
  401: '未取得授权(401)',
  403: '拒绝访问(403)',
  404: '资源不存在(404)',
  405: '该功能被禁用(405)',
  408: '请求超时(408)',
  409: '数据冲突(409)',
  410: '数据已删除(410)',
  500: '服务器错误(500)',
  501: '服务未实现(501)',
  502: '网络错误(502)',
  503: '服务不可用(503)',
  504: '网络超时(504)',
  505: 'HTTP版本不受支持(505)'
}
